pub struct Fe32(/* private fields */);Expand description
An element in GF(32), the finite field containing elements [0,31] inclusive.
Implementations
Sourceimpl Fe32
impl Fe32
Sourcepub fn iter_alpha() -> impl Iterator<Item = Fe32>
pub fn iter_alpha() -> impl Iterator<Item = Fe32>
Iterator over all field elements, in alphabetical order.
Sourcepub fn from_char(c: char) -> Result<Fe32, FromCharError>
pub fn from_char(c: char) -> Result<Fe32, FromCharError>
Creates a field element from a single bech32 character.
Errors
If the input char is not part of the bech32 alphabet.
Sourcepub fn from_char_unchecked(c: u8) -> Fe32
pub fn from_char_unchecked(c: u8) -> Fe32
Creates a field element from a single bech32 character.
Panics
If the input character is not part of the bech32 alphabet.