ConsensusVersion

Enum ConsensusVersion 

#[repr(u16)]
pub enum ConsensusVersion {
Show 14 variants V1 = 1, V2 = 2, V3 = 3, V4 = 4, V5 = 5, V6 = 6, V7 = 7, V8 = 8, V9 = 9, V10 = 10, V11 = 11, V12 = 12, V13 = 13, V14 = 14,
}
The different consensus versions. If you need the version active for a specific height, see: N::CONSENSUS_VERSION.

Variants



V1 = 1

V1: The initial genesis consensus version.



V2 = 2

V2: Update to the block reward and execution cost algorithms.



V3 = 3

V3: Update to the number of validators and finalize scope RNG seed.



V4 = 4

V4: Update to the Varuna version.



V5 = 5

V5: Update to the number of validators and enable batch proposal spend limits.



V6 = 6

V6: Update to the number of validators.



V7 = 7

V7: Update to program rules.



V8 = 8

V8: Update to inclusion version, record commitment version, and introduces sender ciphertexts.



V9 = 9

V9: Support for program upgradability.



V10 = 10

V10: Lower fees, appropriate record output type checking.



V11 = 11

V11: Expand array size limit to 512 and introduce ECDSA signature verification opcodes.



V12 = 12

V12: Prevent connection to forked nodes, disable StringType, enable block timestamp.



V13 = 13

V13: Introduces external structs.



V14 = 14

V14: Increase the program size limit to 512 kB, the transaction size limit to 540 kB, the array size limit to 2048, and the Future argument bit size to 32 bits. Introduces aleo::GENERATOR, aleo::GENERATOR_POWERS, snark.verify opcodes, and dynamic dispatch, and identifier literal types.

Implementations