pub trait Compare<Rhs = Self>where
Rhs: ?Sized,{
type Output;
// Required methods
fn is_less_than(&self, other: &Rhs) -> Self::Output;
fn is_greater_than(&self, other: &Rhs) -> Self::Output;
fn is_less_than_or_equal(&self, other: &Rhs) -> Self::Output;
fn is_greater_than_or_equal(&self, other: &Rhs) -> Self::Output;
}Expand description
Trait for comparator operations.
Required Associated Types
Required Methods
Sourcefn is_less_than(&self, other: &Rhs) -> Self::Output
fn is_less_than(&self, other: &Rhs) -> Self::Output
Returns true if self is less than other.
Sourcefn is_greater_than(&self, other: &Rhs) -> Self::Output
fn is_greater_than(&self, other: &Rhs) -> Self::Output
Returns true if self is greater than other.
Sourcefn is_less_than_or_equal(&self, other: &Rhs) -> Self::Output
fn is_less_than_or_equal(&self, other: &Rhs) -> Self::Output
Returns true if self is less than or equal to other.
Sourcefn is_greater_than_or_equal(&self, other: &Rhs) -> Self::Output
fn is_greater_than_or_equal(&self, other: &Rhs) -> Self::Output
Returns true if self is greater than or equal to other.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<E> Compare for Field<E>where
E: Environment,
impl<E> Compare for Field<E>where
E: Environment,
Sourcefn is_less_than(&self, other: &Field<E>) -> <Field<E> as Compare>::Output
fn is_less_than(&self, other: &Field<E>) -> <Field<E> as Compare>::Output
Returns true if self is less than other.
Sourcefn is_greater_than(&self, other: &Field<E>) -> <Field<E> as Compare>::Output
fn is_greater_than(&self, other: &Field<E>) -> <Field<E> as Compare>::Output
Returns true if self is greater than other.
Sourcefn is_less_than_or_equal(
&self,
other: &Field<E>,
) -> <Field<E> as Compare>::Output
fn is_less_than_or_equal( &self, other: &Field<E>, ) -> <Field<E> as Compare>::Output
Returns true if self is less than or equal to other.
Sourcefn is_greater_than_or_equal(
&self,
other: &Field<E>,
) -> <Field<E> as Compare>::Output
fn is_greater_than_or_equal( &self, other: &Field<E>, ) -> <Field<E> as Compare>::Output
Returns true if self is greater than or equal to other.
type Output = Boolean<E>
Sourceimpl<E> Compare for Scalar<E>where
E: Environment,
impl<E> Compare for Scalar<E>where
E: Environment,
Sourcefn is_less_than(&self, other: &Scalar<E>) -> <Scalar<E> as Compare>::Output
fn is_less_than(&self, other: &Scalar<E>) -> <Scalar<E> as Compare>::Output
Returns true if self is less than other.
Sourcefn is_greater_than(&self, other: &Scalar<E>) -> <Scalar<E> as Compare>::Output
fn is_greater_than(&self, other: &Scalar<E>) -> <Scalar<E> as Compare>::Output
Returns true if self is greater than other.
Sourcefn is_less_than_or_equal(
&self,
other: &Scalar<E>,
) -> <Scalar<E> as Compare>::Output
fn is_less_than_or_equal( &self, other: &Scalar<E>, ) -> <Scalar<E> as Compare>::Output
Returns true if self is less than or equal to other.
Sourcefn is_greater_than_or_equal(
&self,
other: &Scalar<E>,
) -> <Scalar<E> as Compare>::Output
fn is_greater_than_or_equal( &self, other: &Scalar<E>, ) -> <Scalar<E> as Compare>::Output
Returns true if self is greater than or equal to other.
type Output = Boolean<E>
Sourceimpl<E, I> Compare for Integer<E, I>where
E: Environment,
I: IntegerType,
impl<E, I> Compare for Integer<E, I>where
E: Environment,
I: IntegerType,
Sourcefn is_less_than(
&self,
other: &Integer<E, I>,
) -> <Integer<E, I> as Compare>::Output
fn is_less_than( &self, other: &Integer<E, I>, ) -> <Integer<E, I> as Compare>::Output
Returns true if self is less than other.
Sourcefn is_greater_than(
&self,
other: &Integer<E, I>,
) -> <Integer<E, I> as Compare>::Output
fn is_greater_than( &self, other: &Integer<E, I>, ) -> <Integer<E, I> as Compare>::Output
Returns true if self is greater than other.
Sourcefn is_less_than_or_equal(
&self,
other: &Integer<E, I>,
) -> <Integer<E, I> as Compare>::Output
fn is_less_than_or_equal( &self, other: &Integer<E, I>, ) -> <Integer<E, I> as Compare>::Output
Returns true if self is less than or equal to other.
Sourcefn is_greater_than_or_equal(
&self,
other: &Integer<E, I>,
) -> <Integer<E, I> as Compare>::Output
fn is_greater_than_or_equal( &self, other: &Integer<E, I>, ) -> <Integer<E, I> as Compare>::Output
Returns true if self is greater than or equal to other.